==> haskell-hls-explicit-record-fields-plugin-2.0.0.0-49-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-record-fields-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-record-fields-plugin
version:              2.0.0.0
visibility:           public
id:
    hls-explicit-record-fields-plugin-2.0.0.0-ATHCvZzKTae5NcNe7mKtyy

key:
    hls-explicit-record-fields-plugin-2.0.0.0-ATHCvZzKTae5NcNe7mKtyy

license:              BSD-3-Clause
maintainer:           berk.ozkutuk@tweag.io
author:               Berk Ozkutuk
synopsis:             Explicit record fields plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  dd3759031b63ef7ebc72fd1df34adcc5
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitFields
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-record-fields-plugin-2.0.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-record-fields-plugin-2.0.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-record-fields-plugin-2.0.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-record-fields-plugin
hs-libraries:
    HShls-explicit-record-fields-plugin-2.0.0.0-ATHCvZzKTae5NcNe7mKtyy

depends:
    base-4.17.2.1 containers-0.6.7 ghc-boot-th-9.4.8
    ghcide-2.0.0.0-AOKTdr7dUo5E6gpExUmSTV
    hls-graph-2.0.0.0-BGpiuUBrZCwCsk1CEbbWzd
    hls-plugin-api-2.0.0.0-iaubCJYxPJACQ6RJA0OFe
    lens-5.2.3-CV81uxSR0PiAcO8XtynZEb
    lsp-1.6.0.0-KkAghWQ0BKUEqGKLNhvLs1
    syb-0.7.2.4-7bSc04XXCdy5oWDf8UOHZs text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-2kG5VEC3Gy42AwINT9WJ9w

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-record-fields-plugin/html/hls-explicit-record-fields-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-explicit-record-fields-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-explicit-record-fields-plugin-2.0.0.0-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-record-fields-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-record-fields-plugin
version:              2.0.0.0
visibility:           public
id:
    hls-explicit-record-fields-plugin-2.0.0.0-Ltnlsf9WtAp9zmhwOFHFYY

key:
    hls-explicit-record-fields-plugin-2.0.0.0-Ltnlsf9WtAp9zmhwOFHFYY

license:              BSD-3-Clause
maintainer:           berk.ozkutuk@tweag.io
author:               Berk Ozkutuk
synopsis:             Explicit record fields plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  47325f0e313ddd85760becf74ac32f7b
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitFields
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-record-fields-plugin-2.0.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-record-fields-plugin-2.0.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-record-fields-plugin-2.0.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-record-fields-plugin
hs-libraries:
    HShls-explicit-record-fields-plugin-2.0.0.0-Ltnlsf9WtAp9zmhwOFHFYY

depends:
    base-4.17.2.1 containers-0.6.7 ghc-boot-th-9.4.8
    ghcide-2.0.0.0-EHxX854jmvwD5ulayIxyx6
    hls-graph-2.0.0.0-Dwoowae560dEfZKoVLM8Ap
    hls-plugin-api-2.0.0.0-G44fQLihVWI1U4TjtZEXnI
    lens-5.2.3-J1GK3I4tdtMEzlekK9vBY2
    lsp-1.6.0.0-2EqnYNOWy2LCyRUoXrjR35
    syb-0.7.2.4-HJAbU0lurQkHN7nU4EHwhb text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-Jl6TkouWI2i1D1jczNV0uv

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-record-fields-plugin/html/hls-explicit-record-fields-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-explicit-record-fields-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
